==> jakarta-jakartaeetck-8.0.3.zip: jakartaeetck/src/com/sun/ts/tests/ejb30/lite/interceptor/singleton/business/annotated/InterceptorBean.java <==
/*
 * Copyright (c) 2007, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

/*
 * $Id$
 */
package com.sun.ts.tests.ejb30.lite.interceptor.singleton.business.annotated;

import com.sun.ts.tests.ejb30.lite.interceptor.common.business.Interceptor4;
import com.sun.ts.tests.ejb30.lite.interceptor.common.business.Interceptor5;
import com.sun.ts.tests.ejb30.lite.interceptor.common.business.InterceptorBaseBase;
import com.sun.ts.tests.ejb30.lite.interceptor.common.business.InterceptorBeanBase;
import com.sun.ts.tests.ejb30.lite.interceptor.common.business.InterceptorIF;
import javax.ejb.Singleton;
import javax.interceptor.AroundInvoke;
import javax.interceptor.Interceptors;
import javax.interceptor.InvocationContext;

@Singleton
@Interceptors({ Interceptor5.class, Interceptor4.class })
public class InterceptorBean extends InterceptorBeanBase
    implements InterceptorIF {
  private static final String simpleName = "InterceptorBean";

  @SuppressWarnings("unused")
  @AroundInvoke
  private Object intercep(InvocationContext inv) throws Exception {
    InterceptorBaseBase.addToHistory(inv, simpleName);
    return inv.proceed();
  }
}

==> jakarta-jakartaeetck-9.0.0.zip: jakartaeetck/src/com/sun/ts/tests/ejb30/lite/interceptor/singleton/business/annotated/InterceptorBean.java <==
/*
 * Copyright (c) 2007, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

/*
 * $Id$
 */
package com.sun.ts.tests.ejb30.lite.interceptor.singleton.business.annotated;

import com.sun.ts.tests.ejb30.lite.interceptor.common.business.Interceptor4;
import com.sun.ts.tests.ejb30.lite.interceptor.common.business.Interceptor5;
import com.sun.ts.tests.ejb30.lite.interceptor.common.business.InterceptorBaseBase;
import com.sun.ts.tests.ejb30.lite.interceptor.common.business.InterceptorBeanBase;
import com.sun.ts.tests.ejb30.lite.interceptor.common.business.InterceptorIF;
import jakarta.ejb.Singleton;
import jakarta.interceptor.AroundInvoke;
import jakarta.interceptor.Interceptors;
import jakarta.interceptor.InvocationContext;

@Singleton
@Interceptors({ Interceptor5.class, Interceptor4.class })
public class InterceptorBean extends InterceptorBeanBase
    implements InterceptorIF {
  private static final String simpleName = "InterceptorBean";

  @SuppressWarnings("unused")
  @AroundInvoke
  private Object intercep(InvocationContext inv) throws Exception {
    InterceptorBaseBase.addToHistory(inv, simpleName);
    return inv.proceed();
  }
}
